@@ -1,4 +1,4 @@
-/* This file is part of RTags (http://rtags.net).
+/* This file is part of RTags (https://github.com/Andersbakken/rtags).
 
    RTags is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with RTags.  If not, see <http://www.gnu.org/licenses/>. */
+   along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
 #include "JobScheduler.h"
 
@@ -110,6 +110,25 @@ void JobScheduler::startJobs()
     int slots = std::max<int>(0, options.jobCount - mActiveByProcess.size());
     int daemonSlots = std::max<int>(0, options.daemonCount - mActiveDaemonsByProcess.size());
 
+    debug() << "JobScheduler::startJobs" << "jobCount" << options.jobCount << "active" << mActiveByProcess.size() << "\n"
+            << "slots" << slots << "daemonCount" << options.daemonCount << "active daemons" << mActiveDaemonsByProcess.size() << "\n"
+            << "daemonSlots" << daemonSlots;
+
+    if (options.jobCount < mActiveByProcess.size()) {
+        List<std::shared_ptr<Node> > nodes;
+        nodes.reserve(mActiveByProcess.size());
+        for (const auto &pair : mActiveByProcess) {
+            nodes.push_back(pair.second);
+        }
+        std::sort(nodes.begin(), nodes.end(), [](const std::shared_ptr<Node> &l, const std::shared_ptr<Node> &r) -> bool {
+            return l->started > r->started;
+        });
+        const size_t c = mActiveByProcess.size() - options.jobCount;
+        for (size_t i=0; i<c; ++i) {
+            debug() << "Killing process" << nodes[i]->started;
+            nodes[i]->process->kill();
+        }
+    }
     std::shared_ptr<Node> node = mPendingJobs.first();
     while (node && (slots || daemonSlots)) {
         const Server::ActiveBufferType type = Server::instance()->activeBufferType(node->job->sourceFileId());
@@ -137,6 +156,7 @@ void JobScheduler::startJobs()
                 assert(!(node->job->flags & (IndexerJob::Crashed|IndexerJob::Aborted|IndexerJob::Complete|IndexerJob::Running)));
                 node->job->flags |= IndexerJob::Running|IndexerJob::EditorActive;
                 node->daemon = true;
+                debug() << "starting daemon job" << node->job->sourceFile;
                 cand->first->write(node->job->encode());
                 node->started = Rct::monoMs();
                 mActiveDaemonsByProcess[cand->first] = node;
@@ -151,7 +171,7 @@ void JobScheduler::startJobs()
         }
         if (slots) {
             Process *process = new Process;
-            debug() << "Starting process for" << node->job->id << node->job->sourceFileId() << node->job.get();
+            debug() << "Starting process for" << node->job->id << node->job->sourceFile << node->job.get();
             List<String> arguments;
             arguments << "--priority" << String::number(node->job->priority());
             for (int i=logLevel().toInt(); i>0; --i)
@@ -339,7 +359,7 @@ void JobScheduler::sort()
 
 void JobScheduler::onProcessReadyReadStdErr(Process *proc)
 {
-    std::shared_ptr<Node> n = mActiveByProcess[proc];
+    std::shared_ptr<Node> n = mActiveByProcess.value(proc);
     String out = proc->readAllStdErr();
     if (n)
         n->stdErr.append(out);
@@ -389,7 +409,7 @@ void JobScheduler::onProcessReadyReadStdOut(Process *proc)
             data.cache = n->job->sources;
             data.touched = Rct::monoMs();
             assert(n->process == proc);
-            n->process = 0;
+            n->process = nullptr;
             assert(!(n->job->flags & IndexerJob::Aborted));
             startJobs();
         }
@@ -413,7 +433,7 @@ void JobScheduler::onProcessFinished(Process *proc, pid_t pid)
 
     if (n) {
         assert(n->process == proc);
-        n->process = 0;
+        n->process = nullptr;
         assert(!(n->job->flags & IndexerJob::Aborted));
         if (!(n->job->flags & IndexerJob::Complete) && proc->returnCode() != 0) {
             auto nodeById = mActiveById.take(n->job->id);
