@@ -1,4 +1,4 @@
-/* This file is part of RTags (http://rtags.net).
+/* This file is part of RTags (https://github.com/Andersbakken/rtags).
 
    RTags is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with RTags.  If not, see <http://www.gnu.org/licenses/>. */
+   along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
 #include "RClient.h"
 
@@ -99,7 +99,6 @@ std::initializer_list<CommandLineParser::Option<RClient::OptionType> > opts = {
     { RClient::Dependencies, "dependencies", 0, CommandLineParser::Required, "Dump dependencies for source file [(includes, included-by, depends-on, depended-on, tree-depends-on, raw)]." },
     { RClient::AllDependencies, "all-dependencies", 0, CommandLineParser::NoValue, "Dump dependencies for all source files [(includes, included-by, depends-on, depended-on, tree-depends-on, raw)]." },
     { RClient::ReloadFileManager, "reload-file-manager", 'B', CommandLineParser::NoValue, "Reload file manager." },
-    { RClient::Man, "man", 0, CommandLineParser::NoValue, "Output XML for xmltoman to generate man page for rc :-)" },
     { RClient::CodeCompleteAt, "code-complete-at", 'l', CommandLineParser::Required, "Code complete at location: arg is file:line:col." },
     { RClient::SendDiagnostics, "send-diagnostics", 0, CommandLineParser::Required, "Only for debugging. Send data to all -G connections." },
     { RClient::DumpCompletions, "dump-completions", 0, CommandLineParser::NoValue, "Dump cached completions." },
@@ -147,6 +146,7 @@ std::initializer_list<CommandLineParser::Option<RClient::OptionType> > opts = {
     { RClient::SymbolInfoIncludeTargets, "symbol-info-include-targets", 0, CommandLineParser::NoValue, "Use to make --symbol-info include target symbols." },
     { RClient::SymbolInfoIncludeReferences, "symbol-info-include-references", 0, CommandLineParser::NoValue, "Use to make --symbol-info include reference symbols." },
     { RClient::SymbolInfoIncludeBaseClasses, "symbol-info-include-base-classes", 0, CommandLineParser::NoValue, "Use to make --symbol-info include baseclasses' symbols." },
+    { RClient::SymbolInfoIncludeSourceCode, "symbol-info-include-source-code", 0, CommandLineParser::NoValue, "Use to make --symbol-info include source code." },
     { RClient::CursorKind, "cursor-kind", 0, CommandLineParser::NoValue, "Include cursor kind in --find-symbols output." },
     { RClient::DisplayName, "display-name", 0, CommandLineParser::NoValue, "Include display name in --find-symbols output." },
     { RClient::CurrentFile, "current-file", 0, CommandLineParser::Required, "Pass along which file is being edited to give rdm a better chance at picking the right project." },
@@ -180,7 +180,7 @@ std::initializer_list<CommandLineParser::Option<RClient::OptionType> > opts = {
     { RClient::NoRealPath, "no-realpath", 0, CommandLineParser::NoValue, "Don't resolve paths using realpath(3)." },
     { RClient::IncludePath, "include-path", 0, CommandLineParser::Required, "Dump include path for symbol." },
     { RClient::MaxDepth, "max-depth", 0, CommandLineParser::Required, "Max search depth. Used for --include-path." },
-    { RClient::None, String(), 0, CommandLineParser::NoValue, 0 }
+    { RClient::None, String(), 0, CommandLineParser::NoValue, nullptr }
 };
 
 class RCCommand
@@ -366,7 +366,7 @@ void RClient::exec()
 {
     RTags::initMessages();
     OnDestruction onDestruction([]() { Message::cleanup(); });
-    EventLoop::SharedPtr loop(new EventLoop);
+    std::shared_ptr<EventLoop> loop(new EventLoop);
     loop->init(EventLoop::MainEventLoop);
 
     const int commandCount = mCommands.size();
@@ -458,10 +458,6 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
             CommandLineParser::help(stdout, "rc", opts);
             mExitCode = RTags::Success;
             return { String(), CommandLineParser::Parse_Ok } ; }
-        case Man: {
-            CommandLineParser::man(opts);
-            mExitCode = RTags::Success;
-            return { String(), CommandLineParser::Parse_Ok }; }
         case SocketFile: {
             mSocketFile = std::move(value);
             break; }
@@ -540,6 +536,9 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
         case SymbolInfoIncludeBaseClasses: {
             mQueryFlags |= QueryMessage::SymbolInfoIncludeBaseClasses;
             break; }
+        case SymbolInfoIncludeSourceCode: {
+            mQueryFlags |= QueryMessage::SymbolInfoIncludeSourceCode;
+            break; }
         case CursorKind: {
             mQueryFlags |= QueryMessage::CursorKind;
             break; }
@@ -636,7 +635,7 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
             mExitCode = RTags::Success;
             return { String(), CommandLineParser::Parse_Ok }; }
         case VerifyVersion: {
-            const int version = strtoul(value.constData(), 0, 10);
+            const int version = strtoul(value.constData(), nullptr, 10);
             if (version != NumOptions) {
                 fprintf(stdout, "Protocol version mismatch got: %d expected: %d \n", version, NumOptions);
                 mExitCode = RTags::ProtocolFailure;
@@ -652,7 +651,7 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
                 return { String::format<1024>("Can't resolve argument %s", value.constData()), CommandLineParser::Parse_Error };
             }
 
-            addQuery(QueryMessage::CodeCompleteAt, std::move(encoded));
+            addQuery(QueryMessage::CodeCompleteAt, std::move(encoded), QueryMessage::HasLocation);
             break; }
         case Silent: {
             mLogLevel = LogLevel::None;
@@ -884,7 +883,6 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
         case IncludeFile:
         case JobCount:
         case Status: {
-            Flags<QueryMessage::Flag> extraQueryFlags;
             QueryMessage::Type queryType = QueryMessage::Invalid;
             bool resolve = true;
             switch (type) {
@@ -938,12 +936,12 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
                 Path p(arg);
                 if (resolve && p.exists()) {
                     p.resolve();
-                    addQuery(queryType, std::move(p), extraQueryFlags);
+                    addQuery(queryType, std::move(p), QueryMessage::HasLocation);
                 } else {
-                    addQuery(queryType, std::move(arg), extraQueryFlags);
+                    addQuery(queryType, std::move(arg));
                 }
             } else {
-                addQuery(queryType, String(), extraQueryFlags);
+                addQuery(queryType, String());
             }
             assert(!mCommands.isEmpty());
             if (queryType == QueryMessage::Project)
@@ -1073,7 +1071,7 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
             }
             if (p.isDir() && !p.endsWith('/'))
                 p.append('/');
-            addQuery(QueryMessage::HasFileManager, std::move(p));
+            addQuery(QueryMessage::HasFileManager, std::move(p), QueryMessage::HasMatch);
             break; }
         case ProjectRoot: {
             Path p = std::move(value);
@@ -1181,9 +1179,11 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
                     p.append('/');
                 }
             }
-            if (!p.isEmpty())
-                p.resolve();
             Flags<QueryMessage::Flag> extraQueryFlags;
+            if (!p.isEmpty()) {
+                p.resolve();
+                extraQueryFlags |= QueryMessage::HasMatch;
+            }
             QueryMessage::Type queryType = QueryMessage::Invalid;
             switch (type) {
             case GenerateTest:
@@ -1278,7 +1278,7 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
             if (!p.isFile()) {
                 return { String::format<1024>("%s is not a file", p.constData()), CommandLineParser::Parse_Error };
             }
-            addQuery(QueryMessage::PreprocessFile, std::move(p));
+            addQuery(QueryMessage::PreprocessFile, std::move(p), QueryMessage::HasMatch);
             break; }
         case AsmFile: {
             Path p = std::move(value);
@@ -1286,14 +1286,14 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
             if (!p.isFile()) {
                 return { String::format<1024>("%s is not a file", p.constData()), CommandLineParser::Parse_Error };
             }
-            addQuery(QueryMessage::AsmFile, std::move(p));
+            addQuery(QueryMessage::AsmFile, std::move(p), QueryMessage::HasMatch);
             break; }
         case RemoveFile: {
             Path p = Path::resolved(value, Path::MakeAbsolute);
             if (!p.exists()) {
-                addQuery(QueryMessage::RemoveFile, std::move(p));
+                addQuery(QueryMessage::RemoveFile, std::move(p), QueryMessage::HasMatch);
             } else {
-                addQuery(QueryMessage::RemoveFile, std::move(value));
+                addQuery(QueryMessage::RemoveFile, std::move(value), QueryMessage::HasMatch);
             }
             break; }
         case ReferenceName: {
@@ -1305,7 +1305,7 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
                 return { String::format<1024>("include path can't resolve argument %s", value.constData()), CommandLineParser::Parse_Error };
             }
 
-            addQuery(QueryMessage::IncludePath, std::move(encoded));
+            addQuery(QueryMessage::IncludePath, std::move(encoded), QueryMessage::HasLocation);
             break; }
         case MaxDepth: {
             const int depth = atoi(value.constData());
