@@ -1,4 +1,4 @@
-/* This file is part of RTags (http://rtags.net).
+/* This file is part of RTags (https://github.com/Andersbakken/rtags).
 
    RTags is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with RTags.  If not, see <http://www.gnu.org/licenses/>. */
+   along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
 #ifndef RTags_h
 #define RTags_h
@@ -201,7 +201,7 @@ struct TranslationUnit {
 struct CreateLocation
 {
     virtual ~CreateLocation() {}
-    inline Location createLocation(const CXSourceLocation &location, bool *blocked = 0, unsigned *offset = 0)
+    inline Location createLocation(const CXSourceLocation &location, bool *blocked = nullptr, unsigned *offset = nullptr)
     {
         CXString fileName;
         unsigned int line, col;
@@ -226,7 +226,7 @@ struct CreateLocation
         const Location ret = createLocation(path, line, col, blocked);
         return ret;
     }
-    inline Location createLocation(CXFile file, unsigned int line, unsigned int col, bool *blocked = 0)
+    inline Location createLocation(CXFile file, unsigned int line, unsigned int col, bool *blocked = nullptr)
     {
         if (blocked)
             *blocked = false;
@@ -243,7 +243,7 @@ struct CreateLocation
         clang_disposeString(fn);
         return createLocation(p, line, col, blocked);
     }
-    inline Location createLocation(const CXCursor &cursor, bool *blocked = 0, unsigned *offset = 0)
+    inline Location createLocation(const CXCursor &cursor, bool *blocked = nullptr, unsigned *offset = nullptr)
     {
         const CXSourceLocation location = clang_getCursorLocation(cursor);
         if (!location)
@@ -251,7 +251,7 @@ struct CreateLocation
         return createLocation(location, blocked, offset);
     }
 
-    virtual Location createLocation(const Path &file, unsigned int line, unsigned int col, bool *blocked = 0) = 0;
+    virtual Location createLocation(const Path &file, unsigned int line, unsigned int col, bool *blocked = nullptr) = 0;
 };
 
 struct DiagnosticsProvider
@@ -268,7 +268,7 @@ struct DiagnosticsProvider
         return clang_getCursor(unit(idx), location);
     }
 
-    inline Location createLocation(const CXSourceLocation &location, bool *blocked = 0, unsigned *offset = 0)
+    inline Location createLocation(const CXSourceLocation &location, bool *blocked = nullptr, unsigned *offset = nullptr)
     {
         CXString fileName;
         unsigned int line, col;
@@ -293,7 +293,7 @@ struct DiagnosticsProvider
         const Location ret = createLocation(path, line, col, blocked);
         return ret;
     }
-    inline Location createLocation(CXFile file, unsigned int line, unsigned int col, bool *blocked = 0)
+    inline Location createLocation(CXFile file, unsigned int line, unsigned int col, bool *blocked = nullptr)
     {
         if (blocked)
             *blocked = false;
@@ -314,11 +314,11 @@ struct DiagnosticsProvider
         }
         return createLocation(p, line, col, blocked);
     }
-    Location createLocation(const CXCursor &cursor, CXCursorKind kind = CXCursor_FirstInvalid, bool *blocked = 0, unsigned *offset = 0);
+    Location createLocation(const CXCursor &cursor, CXCursorKind kind = CXCursor_FirstInvalid, bool *blocked = nullptr, unsigned *offset = nullptr);
     virtual size_t unitCount() const = 0;
     virtual size_t diagnosticCount(size_t unit) const = 0;
     virtual CXDiagnostic diagnostic(size_t unit, size_t idx) const = 0;
-    virtual Location createLocation(const Path &file, unsigned int line, unsigned int col, bool *blocked = 0) = 0;
+    virtual Location createLocation(const Path &file, unsigned int line, unsigned int col, bool *blocked = nullptr) = 0;
     virtual uint32_t sourceFileId() const = 0;
     virtual IndexDataMessage &indexDataMessage() = 0;
     virtual CXTranslationUnit unit(size_t unit) const = 0;
@@ -330,9 +330,9 @@ struct Auto {
     CXCursor cursor;
     CXType type;
 };
-bool resolveAuto(const CXCursor &cursor, Auto *a = 0);
+bool resolveAuto(const CXCursor &cursor, Auto *a = nullptr);
 
-int cursorArguments(const CXCursor &cursor, List<CXCursor> *args = 0);
+int cursorArguments(const CXCursor &cursor, List<CXCursor> *args = nullptr);
 
 struct Filter
 {
@@ -407,7 +407,7 @@ inline const char *tokenKindSpelling(CXTokenKind kind)
     case CXToken_Literal: return "Literal";
     case CXToken_Comment: return "Comment";
     }
-    return 0;
+    return nullptr;
 }
 
 template <typename T>
@@ -571,7 +571,7 @@ inline bool needsQualifiers(CXCursorKind kind)
 String typeName(const CXCursor &cursor);
 inline const char *builtinTypeName(CXTypeKind kind)
 {
-    const char *ret = 0;
+    const char *ret = nullptr;
     switch (kind) {
     case CXType_Void: ret = "void"; break;
     case CXType_Bool: ret = "bool"; break;
@@ -625,7 +625,7 @@ inline const char *completionChunkKindSpelling(CXCompletionChunkKind kind)
     case CXCompletionChunk_HorizontalSpace: return "HorizontalSpace";
     case CXCompletionChunk_VerticalSpace: return "VerticalSpace";
     }
-    return 0;
+    return nullptr;
 }
 
 String typeString(const CXType &type);
@@ -776,15 +776,16 @@ enum ProjectRootMode {
     SourceRoot,
     BuildRoot
 };
-Path findProjectRoot(const Path &path, ProjectRootMode mode, SourceCache *cache = 0);
+size_t findOffset(int line, int col, const String &contents, size_t offset = 0);
+Path findProjectRoot(const Path &path, ProjectRootMode mode, SourceCache *cache = nullptr);
 enum FindAncestorFlag {
     Shallow = 0x1,
     Wildcard = 0x2,
     Authoritative = 0x4
 };
 RCT_FLAGS(FindAncestorFlag);
-Path findAncestor(const Path& path, const String &fn, Flags<FindAncestorFlag> flags, SourceCache *cache = 0);
-Map<String, String> rtagsConfig(const Path &path, SourceCache *cache = 0);
+Path findAncestor(const Path& path, const String &fn, Flags<FindAncestorFlag> flags, SourceCache *cache = nullptr);
+Map<String, String> rtagsConfig(const Path &path, SourceCache *cache = nullptr);
 
 enum { DefinitionBit = 0x1000 };
 inline CXCursorKind targetsValueKind(uint16_t val)
@@ -950,7 +951,7 @@ inline const String elispEscape(const String &data)
 }
 String toElisp(const Value &value);
 
-inline Location createLocation(CXSourceLocation loc, int *offsetPtr = 0)
+inline Location createLocation(CXSourceLocation loc, int *offsetPtr = nullptr)
 {
     if (offsetPtr)
         *offsetPtr = -1;
@@ -980,7 +981,7 @@ inline Location createLocation(CXSourceLocation loc, int *offsetPtr = 0)
     return Location(fileId, line, col);
 }
 
-inline Location createLocation(const CXCursor &cursor, int *offsetPtr = 0)
+inline Location createLocation(const CXCursor &cursor, int *offsetPtr = nullptr)
 {
     return createLocation(clang_getCursorLocation(cursor), offsetPtr);
 }
@@ -1048,6 +1049,7 @@ inline Log operator<<(Log dbg, CXType type);
 inline Log operator<<(Log dbg, CXCursorKind kind);
 inline Log operator<<(Log dbg, CXTypeKind kind);
 inline Log operator<<(Log dbg, CXLinkageKind kind);
+inline Log operator<<(Log dbg, CXCompletionChunkKind kind);
 
 class CXStringScope
 {
@@ -1117,6 +1119,34 @@ inline Log operator<<(Log dbg, CXLinkageKind kind)
     return dbg;
 }
 
+inline Log operator<<(Log dbg, CXCompletionChunkKind kind)
+{
+    switch (kind) {
+    case CXCompletionChunk_Optional: dbg << "CXCompletionChunk_Optional"; break;
+    case CXCompletionChunk_TypedText: dbg << "CXCompletionChunk_TypedText"; break;
+    case CXCompletionChunk_Text: dbg << "CXCompletionChunk_Text"; break;
+    case CXCompletionChunk_Placeholder: dbg << "CXCompletionChunk_Placeholder"; break;
+    case CXCompletionChunk_Informative: dbg << "CXCompletionChunk_Informative"; break;
+    case CXCompletionChunk_CurrentParameter: dbg << "CXCompletionChunk_CurrentParameter"; break;
+    case CXCompletionChunk_LeftParen: dbg << "CXCompletionChunk_LeftParen"; break;
+    case CXCompletionChunk_RightParen: dbg << "CXCompletionChunk_RightParen"; break;
+    case CXCompletionChunk_LeftBracket: dbg << "CXCompletionChunk_LeftBracket"; break;
+    case CXCompletionChunk_RightBracket: dbg << "CXCompletionChunk_RightBracket"; break;
+    case CXCompletionChunk_LeftBrace: dbg << "CXCompletionChunk_LeftBrace"; break;
+    case CXCompletionChunk_RightBrace: dbg << "CXCompletionChunk_RightBrace"; break;
+    case CXCompletionChunk_LeftAngle: dbg << "CXCompletionChunk_LeftAngle"; break;
+    case CXCompletionChunk_RightAngle: dbg << "CXCompletionChunk_RightAngle"; break;
+    case CXCompletionChunk_Comma: dbg << "CXCompletionChunk_Comma"; break;
+    case CXCompletionChunk_ResultType: dbg << "CXCompletionChunk_ResultType"; break;
+    case CXCompletionChunk_Colon: dbg << "CXCompletionChunk_Colon"; break;
+    case CXCompletionChunk_SemiColon: dbg << "CXCompletionChunk_SemiColon"; break;
+    case CXCompletionChunk_Equal: dbg << "CXCompletionChunk_Equal"; break;
+    case CXCompletionChunk_HorizontalSpace: dbg << "CXCompletionChunk_HorizontalSpace"; break;
+    case CXCompletionChunk_VerticalSpace: dbg << "CXCompletionChunk_VerticalSpace"; break;
+    }
+    return dbg;
+}
+
 #if CINDEX_VERSION >= CINDEX_VERSION_ENCODE(0, 29)
 inline Log operator<<(Log dbg, CXTemplateArgumentKind kind)
 {
