@@ -1,4 +1,4 @@
-/* This file is part of RTags (http://rtags.net).
+/* This file is part of RTags (https://github.com/Andersbakken/rtags).
 
    RTags is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with RTags.  If not, see <http://www.gnu.org/licenses/>. */
+   along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
 #include "Server.h"
 #include <rct/ThreadPool.h>
@@ -91,10 +91,10 @@ static const List<Path> sSystemIncludePaths = {
 };
 #endif
 
-Server *Server::sInstance = 0;
+Server *Server::sInstance = nullptr;
 Server::Server()
     : mSuspended(false), mEnvironment(Rct::environment()), mPollTimer(-1), mExitCode(0),
-      mLastFileId(0), mCompletionThread(0), mActiveBuffersSet(false)
+      mLastFileId(0), mCompletionThread(nullptr), mActiveBuffersSet(false)
 {
     assert(!sInstance);
     sInstance = this;
@@ -109,13 +109,13 @@ Server::~Server()
         mCompletionThread->stop();
         mCompletionThread->join();
         delete mCompletionThread;
-        mCompletionThread = 0;
+        mCompletionThread = nullptr;
     }
 
     stopServers();
     mProjects.clear(); // need to be destroyed before sInstance is set to 0
     assert(sInstance == this);
-    sInstance = 0;
+    sInstance = nullptr;
     Message::cleanup();
 }
 
@@ -158,7 +158,7 @@ bool Server::init(const Options &options)
             "__builtin_ia32_xsaveopt",
             "__builtin_ia32_xsaveopt64",
             "__builtin_ia32_sbb_u32",
-            0
+            nullptr
         };
         for (int i=0; gccBuiltIntVectorFunctionDefines[i]; ++i) {
             mOptions.defines << Source::Define(String::format<128>("%s(...)", gccBuiltIntVectorFunctionDefines[i]));
@@ -186,6 +186,7 @@ bool Server::init(const Options &options)
         return false;
     }
 
+    mDefaultJobCount = options.jobCount;
     {
         Log l(LogLevel::Error, LogOutput::StdOut|LogOutput::TrailingNewLine);
         l << "Running with" << mOptions.jobCount << "jobs, using args:"
@@ -292,7 +293,7 @@ bool Server::initServers()
 #endif
 
     char *listenFds = getenv("LISTEN_FDS");
-    if (listenFds != NULL) {
+    if (listenFds != nullptr) {
         auto numFDs = atoi(listenFds);
         if (numFDs != 1) {
             error("Unexpected number of sockets from systemd: %d", numFDs);
@@ -351,7 +352,7 @@ std::shared_ptr<Project> Server::addProject(const Path &path)
 void Server::onNewConnection(SocketServer *server)
 {
     while (true) {
-        SocketClient::SharedPtr client = server->nextConnection();
+        std::shared_ptr<SocketClient> client = server->nextConnection();
         if (!client) {
             break;
         }
@@ -359,7 +360,7 @@ void Server::onNewConnection(SocketServer *server)
         if (mOptions.maxSocketWriteBufferSize) {
             client->setMaxWriteBufferSize(mOptions.maxSocketWriteBufferSize);
         }
-        conn->setErrorHandler([](const SocketClient::SharedPtr &, Message::MessageError &&error) {
+        conn->setErrorHandler([](const std::shared_ptr<SocketClient> &, Message::MessageError &&error) {
                 if (error.type == Message::Message_VersionError) {
                     ::error("Wrong version marker. You're probably using mismatched versions of rc and rdm");
                 } else {
@@ -1337,8 +1338,6 @@ void Server::listSymbols(const std::shared_ptr<QueryMessage> &query, const std::
 
 void Server::status(const std::shared_ptr<QueryMessage> &query, const std::shared_ptr<Connection> &conn)
 {
-    conn->client()->setWriteMode(SocketClient::Synchronous);
-
     StatusJob job(query, currentProject());
     const int ret = job.run(conn);
     conn->finish(ret);
@@ -1548,12 +1547,13 @@ void Server::setCurrentProject(const std::shared_ptr<Project> &project)
 std::shared_ptr<Project> Server::projectForQuery(const std::shared_ptr<QueryMessage> &query)
 {
     List<Match> matches;
-    if (query->flags() & QueryMessage::HasLocation)
+    if (query->flags() & QueryMessage::HasLocation) {
         matches << query->location().path();
+    } else if (query->flags() & QueryMessage::HasMatch) {
+        matches << query->match();
+    }
     if (!query->currentFile().isEmpty())
         matches << query->currentFile();
-    if (!(query->flags() & QueryMessage::HasLocation))
-        matches << query->match();
 
     return projectForMatches(matches);
 }
@@ -1672,23 +1672,38 @@ void Server::project(const std::shared_ptr<QueryMessage> &query, const std::shar
 
 void Server::jobCount(const std::shared_ptr<QueryMessage> &query, const std::shared_ptr<Connection> &conn)
 {
+    enum { MaxJobCount = 512 };
     String q = query->query();
     if (q.isEmpty()) {
         conn->write<128>("Running with %zu jobs", mOptions.jobCount);
     } else {
-        int jobCount;
-        bool ok;
+        int jobCount = -1;
+        bool ok = false;
         if (q == "default") {
             ok = true;
-            jobCount = std::max(2, ThreadPool::idealThreadCount());
+            jobCount = mDefaultJobCount;
+        } else if (q == "pop") {
+            if (mJobCountStack.isEmpty()) {
+                conn->write<128>("Job count stack is empty");
+            } else {
+                jobCount = mJobCountStack.back();
+                mJobCountStack.pop_back();
+                ok = true;
+            }
+        } else if (q.startsWith("push:")) {
+            jobCount = q.mid(5).toLongLong(&ok);
+            if (ok && jobCount > 0 && jobCount < MaxJobCount) {
+                mJobCountStack.append(mOptions.jobCount);
+            };
         } else {
             jobCount = q.toLongLong(&ok);
         }
-        if (!ok || jobCount < 0 || jobCount > 100) {
+        if (!ok || jobCount < 0 || jobCount > MaxJobCount) {
             conn->write<128>("Invalid job count %s (%d)", query->query().constData(), jobCount);
         } else {
             mOptions.jobCount = jobCount;
             conn->write<128>("Changed jobs to %zu", mOptions.jobCount);
+            mJobScheduler->startJobs();
         }
     }
     conn->finish();
