@@ -1,4 +1,4 @@
-/* This file is part of RTags (http://rtags.net).
+/* This file is part of RTags (https://github.com/Andersbakken/rtags).
 
    RTags is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with RTags.  If not, see <http://www.gnu.org/licenses/>. */
+   along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
 #ifndef VisitFileResponseMessage_h
 #define VisitFileResponseMessage_h
@@ -31,8 +31,8 @@ public:
     uint32_t fileId() const { return mFileId; }
     bool visit() const { return mVisit; }
 
-    void encode(Serializer &serializer) const { serializer << mFileId << mVisit; }
-    void decode(Deserializer &deserializer) { deserializer >> mFileId >> mVisit; }
+    void encode(Serializer &serializer) const override { serializer << mFileId << mVisit; }
+    void decode(Deserializer &deserializer) override { deserializer >> mFileId >> mVisit; }
 private:
     uint32_t mFileId;
     bool mVisit;
